.. rst-class:: detail

SetGroup
===================

.. currentmodule:: compas_rrc

.. autoclass:: SetGroup

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~SetGroup.__init__
        ~SetGroup.from_msg
    
    